<?php
/*
Plugin Name: Flickr Gallery
Plugin URI: http://wordpress.org/extend/plugins/flickr-gallery/
Description: Use easy shortcodes to insert Flickr galleries and photos (and videos) in your blog.
Author: Dan Coulter
Version: 0.1.1
Author URI: http://dancoulter.com/
*/ 

/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/**
 * @package flickr-gallery
 */

if ( !defined('WP_CONTENT_URL') )
	define( 'WP_CONTENT_URL', get_option('siteurl') . '/wp-content');
if ( !defined('WP_CONTENT_DIR') )
	define( 'WP_CONTENT_DIR', ABSPATH . 'wp-content' );

class DC_FlickrGallery {
	/**
	 * Return the filesystem path that the plugin lives in.
	 *
	 * @return string
	 */
	function getPath() {
		return dirname(__FILE__) . '/';
	}
	
	/**
	 * Returns the URL of the plugin's folder.
	 *
	 * @return string
	 */
	function getURL() {
		return WP_CONTENT_URL.'/plugins/'.basename(dirname(__FILE__)) . '/';
	}
	
	/**
	 * Initializes the phpFlickr object.  Called on WP's init hook.
	 *
	 */
    function init() {
		if ( isset($_GET['batman']) ) {
			delete_option('fg-API-key');
		}
		if ( get_option('fg-API-key') ) {
			global $phpFlickr;
			include_once 'phpFlickr/phpFlickr.php';
			$phpFlickr = new phpFlickr(get_option('fg-API-key'));
			wp_enqueue_script('jquery-ui-tabs');			
		}
		
		if ( $_POST['action'] == 'update' && $_POST['fg-API-key'] && $_POST['page_options'] == 'fg-API-key,fg-user_id,fg-per_page' ) {
			include_once 'phpFlickr/phpFlickr.php';
			$phpFlickr = new phpFlickr($_POST['fg-API-key']);
			switch ( $_POST['fg-user_id-type'] ) {
				case 'name':
					$user = $phpFlickr->people_findByUsername($_POST['fg-user_id']);
					$_POST['fg-user_id'] = $user['id'];
					break;
				case 'email':
					$user = $phpFlickr->people_findByEmail($_POST['fg-user_id']);
					$_POST['fg-user_id'] = $user['id'];
					break;
				case 'url':
					$user = $phpFlickr->urls_lookupUser($_POST['fg-user_id']);
					$_POST['fg-user_id'] = $user['id'];
					break;
			}
		}
    }

    /**
     * Handles the [flickr-gallery] shortcode
     *
     * @param array $attr
     * @param string $content
     * @return string
     */
    function gallery($attr, $content = '') {
		if ( get_option('fg-API-key') ) {
			$id = substr(md5(microtime()), 0, 8);
			global $phpFlickr;
			$attr = shortcode_atts(array(
				'photoset' => null,
				'sort' => null,
				'tags' => null,
				'mode' => null,
				'tag_mode' => 'any',
				'user_id' => (isset($attr['mode']) && $attr['mode'] == 'search') ? null : get_option('fg-user_id'),
				'per_page' => get_option('fg-per_page'),
			), $attr);
			$url = $phpFlickr->urls_getUserPhotos($attr['user_id']);
			
			ob_start();
			switch ($attr['mode']) {
				case 'photoset' :
					$photos = $phpFlickr->photosets_getPhotos($attr['photoset'], null, null, $attr['per_page']);
					if ( count($photos['photo']) ) {
						?>
							<div class="flickr-gallery photoset">
								<?php foreach ( $photos['photo'] as $photo ) : ?>
									<div class="flickr-thumb">
										<a href="<?php echo $url . $photo['id'] ?>"><img title="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" alt="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" src="<?php echo $phpFlickr->buildPhotoURL($photo, 'square') ?>" /></a>
									</div>
								<?php endforeach; ?>
								<div class="clear"></div>
							</div>
						<?php
					}
					break;
				case 'tag' :
					$photos = $phpFlickr->photos_search(array(
						'per_page' => $attr['per_page'],
						'user_id' => $attr['user_id'],
						'tags' => $attr['tags'],
						'sort' => $attr['sort'],
						'tag_mode' => $attr['tag_mode'],
					));
					if ( count($photos['photo']) ) {
						?>
							<div class="flickr-gallery tag">
								<?php foreach ( $photos['photo'] as $photo ) : ?>
									<div class="flickr-thumb">
										<a href="<?php echo $url . $photo['id'] ?>"><img title="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" alt="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" src="<?php echo $phpFlickr->buildPhotoURL($photo, 'square') ?>" /></a>
									</div>
								<?php endforeach; ?>
								<div class="clear"></div>
							</div>
						<?php
					}
					break;
				case 'search' :
					$args = $attr;
					unset($args['mode'],$args['photoset']);
					$photos = $phpFlickr->photos_search($args);
					if ( count($photos['photo']) ) {
						?>
							<div class="flickr-gallery search">
								<?php foreach ( $photos['photo'] as $photo ) : ?>
									<div class="flickr-thumb">
										<a href="http://flickr.com/photos/<?php echo $photo['owner'] . '/' . $photo['id'] ?>"><img title="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" alt="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" src="<?php echo $phpFlickr->buildPhotoURL($photo, 'square') ?>" /></a>
									</div>
								<?php endforeach; ?>
								<div class="clear"></div>
							</div>
						<?php
					}
					break;
				default :
					if ( !empty($attr['user_id']) ) {
						?>
							<div id="gallery-<?php echo $id ?>" class="flickr-gallery">
								<ol>
									<li><a href="#photostream"><span>Photostream</span></a></li>
									<li><a href="#sets"><span>Photosets</span></a></li>
									<li><a href="#interesting"><span>Most Interesting</span></a></li>
								</ol>
								<div id="photostream">
									<?php $photos = $phpFlickr->people_getPublicPhotos($attr['user_id'], null, $attr['per_page']); ?>
									<div class="flickr-photos">
										<?php foreach ( $photos['photo'] as $photo ) : ?>
											<div class="flickr-thumb">
												<a href="<?php echo $url . $photo['id'] ?>"><img title="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" alt="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" src="<?php echo $phpFlickr->buildPhotoURL($photo, 'square') ?>" /></a>
											</div>
										<?php endforeach; ?>
									</div>
									<div class="clear"></div>
								</div>
								<div id="sets">
									<?php
										$sets = $phpFlickr->photosets_getList($attr['user_id']);
										foreach( $sets['photoset'] as $set ) :
											?>
												<div class="flickr-set">
													<div class="flickr-thumb">
														<a href="<?php echo $url ?>sets/<?php echo $set['id']; ?>/"><img title="<?php echo str_replace("\"", "\\\"", $set['title']) ?>" alt="<?php echo str_replace("\"", "\\\"", $set['title']) ?>" class="flickr-thumb" src="http://farm<?php echo $set['farm']; ?>.static.flickr.com/<?php echo $set['server']; ?>/<?php echo $set['primary']; ?>_<?php echo $set['secret']; ?>_s.jpg" /></a>
													</div>
													<div class="flickr-set-meta">
					                                    <div class="flickr-set-title"><a href="<?php echo $url ?>sets/<?php echo $set['id']; ?>/"><?php echo $set['title']; ?></a> (<?php echo $set['photos']; ?> photos)</div>
					                                    <div class="flickr-set-description"><?php echo $set['description']; ?></div>
					                                </div>
													<div class="clear"></div>
												</div>
											<?php
										endforeach;
									?>
								</div>
								<div id="interesting">
									<?php
					                    $photos = $phpFlickr->photos_search(array(
					                        'user_id' => $attr['user_id'],
					                        'per_page' => $attr['per_page'],
					                        'sort' => 'interestingness-desc',
					                    ));
									?>
									<div class="flickr-photos">
										<?php foreach ( $photos['photo'] as $photo ) : ?>
											<div class="flickr-thumb">
												<a href="<?php echo $url . $photo['id'] ?>"><img title="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" alt="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" src="<?php echo $phpFlickr->buildPhotoURL($photo, 'square') ?>" /></a>
											</div>
										<?php endforeach; ?>
									</div>
									<div class="clear"></div>
								</div>
							</div>
							<script type="text/javascript">
								jQuery("#gallery-<?php echo $id ?> > ol").tabs();
							</script>
						<?php
					}
					break;
				
			} 
			$result = ob_get_clean();
			return $result;
		}
    }
	
    /**
     * Handles the [flickr][/flickr] shortcode
     *
     * @param array $attr
     * @param string $content
     * @return string
     */
    function image($attr, $content) {
		if ( get_option('fg-API-key') ) {
			global $phpFlickr;
			$attr = shortcode_atts(array(
				'size' => 'medium',
				'float' => 'none',
				'height' => null,
				'width' => null,
			), $attr);

			if ( ereg( '/([0-9]+)/$', $content, $match) ) {
				$id = $match[1];
			} else {
				$id = $content;
			}

			$photo = $phpFlickr->photos_getInfo($id);
			
			if ( isset($photo['id']) ) {
				$url = $phpFlickr->urls_getUserPhotos($photo['owner']['nsid']);
				ob_start();
				if ( 'video' == $photo['media'] ) {
					$sizes = $phpFlickr->photos_getSizes($photo['id']);
					foreach ( $sizes as $size ) {
						if ( $size['label'] == 'Video Player' ) {
							break;
						}
					}
					
					if ( is_null($attr['height']) ) $attr['height'] = $size['height'];
					if ( is_null($attr['width']) ) $attr['width'] = $size['width'];
					?>
						<div class="flickr-gallery video <?php echo $attr['float'] ?>">
							<object type="application/x-shockwave-flash" width="<?php echo $attr['width'] ?>" height="<?php echo $attr['height'] ?>" data="<?php echo $size['source'] ?>" classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000">
								<param name="movie" value="<?php echo $size['source'] ?>"></param>
								<param name="bgcolor" value="#000000"></param>
								<param name="allowFullScreen" value="true"></param>
								<embed type="application/x-shockwave-flash" src="<?php echo $size['source'] ?>" bgcolor="#000000" allowfullscreen="true" flashvars="intl_lang=en-us&amp;photo_secret=b7c2fbe4a3&amp;photo_id=2513132875" height="<?php echo $attr['height'] ?>" width="<?php echo $attr['width'] ?>"></embed>
							</object>
						</div>
					<?php
				} else {
					?>
						<div class="flickr-gallery image <?php echo $attr['float'] ?>"><a href="<?php echo $url . $photo['id'] ?>"><img title="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" alt="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" src="<?php echo $phpFlickr->buildPhotoURL($photo, $attr['size']) ?>" /></a></div>
					<?php
				}
				return ob_get_clean();
			} else {
				return '';
			}
		}
		
    }
	
    /**
     * Sets up the settings page
     *
     */
	function add_settings_page() {
		load_plugin_textdomain('flickr-gallery', dtc_DP_i18n::getPath());
		add_options_page(__('Flickr Gallery', 'flickr-gallery'), __('Flickr Gallery', 'flickr-gallery'), 8, __FILE__, array('DC_FlickrGallery', 'settings_page'));	
	}
	 
	/**
	 * Generates the settings page
	 *
	 */
	function settings_page() {
		global $phpFlickr;
		?>
			<div class="wrap">
				<h2><?php _e('Flickr Gallery', 'flickr-gallery') ?></h2>
				<form method="post" action="options.php">
					<input type="hidden" name="action" value="update" />
					<?php wp_nonce_field('update-options'); ?>
					<input type="hidden" name="page_options" value="fg-API-key,fg-user_id,fg-per_page" />
					<p>
						<?php _e('Flickr <a href="http://www.flickr.com/services/api/keys/">API Key</a>:', 'flickr-gallery') ?>
						<input type="text" name="fg-API-key" value="<?php echo get_option('fg-API-key'); ?>" />
					</p>
					<p>
						<?php _e('Flickr User ID:', 'flickr-gallery') ?>
						<input type="text" name="fg-user_id" value="<?php echo get_option('fg-user_id'); ?>" />
						<select name="fg-user_id-type">
							<option value="id"><?php _e('User ID (12345678@N00)', 'flickr-gallery'); ?></option>
							<option value="name"><?php _e('User Name (the name displayed at the top of your photopage)', 'flickr-gallery'); ?></option>
							<option value="email"><?php _e('Email Address', 'flickr-gallery'); ?></option>
							<option value="url"><?php _e('Flickr photopage URL', 'flickr-gallery'); ?></option>
						</select>
					</p>
					<p>
						<?php _e('Number of photos to display:', 'flickr-gallery') ?>
						<input type="text" name="fg-per_page" value="<?php echo get_option('fg-per_page') ? get_option('fg-per_page') : 60; ?>" />
					</p>
					<p class="submit">
						<input type="submit" name="Submit" value="<?php _e('Save Changes', 'flickr-gallery') ?>" />
					</p>
				</form>
			</div>
		<?php
	}
	
	/**
	 * Inserts the CSS for the plugin into the theme's <head>
	 *
	 */
	function head() {
		?>
			<link href="<?php echo DC_FlickrGallery::getURL() ?>flickr-gallery.css" media="screen" rel="stylesheet" type="text/css" />
		<?php
	}
}

add_shortcode('flickr-gallery', array('DC_FlickrGallery', 'gallery'));
add_shortcode('flickr', array('DC_FlickrGallery', 'image'));

add_action('admin_menu', array('DC_FlickrGallery', 'add_settings_page'));
add_action('init', array('DC_FlickrGallery', 'init'));
add_action('wp_head', array('DC_FlickrGallery', 'head'));
?>
